#include "Input/InputManager.h"
#include "GLFW/glfw3.h"
#include "spdlog/spdlog.h"
#include <iostream>
void BarinkEngine::InputManager::PollEvents()
{
	for (std::vector<BarinkWindow*>::iterator it = windows.begin(); it != windows.end(); ++it) {
		(*it)->Poll();
	}
}

void BarinkEngine::InputManager::KeyCallback(GLFWwindow* window, int key, int scancode, int action, int mods) 
{
	if (key == GLFW_KEY_A && action == GLFW_PRESS)
	{
		
		std::cout << "'a' key was pressed" << std::endl;
	}

}

void BarinkEngine::InputManager::CursorPositionCallback(GLFWwindow* window, double x, double y) 
{
	std::cout << "Cursor Position  x: " << x << ", y: " << y << std::endl;
}

void BarinkEngine::InputManager::CursorEnterCallback(GLFWwindow* window, int entered)
{
	if (entered) {
		// Cursor entered the window's screen space
		std::cout << "Cursor entered!" << std::endl;
	}
	else {
		std::cout << "Cursor left!" << std::endl;
	}
}


void BarinkEngine::InputManager::MouseButtonCallback(GLFWwindow* window, int button, int action, int mods)
{
	if (button == GLFW_MOUSE_BUTTON_RIGHT && action == GLFW_PRESS) {
		std::cout << "Right mouse button was pressed!" << std::endl;
	}

}

void BarinkEngine::InputManager::ScrollCallback(GLFWwindow* window, double xoffset, double yoffset)
{
	std::cout << "Scroll: x: " << xoffset << ", y: " << yoffset << std::endl;
		

}


void BarinkEngine::InputManager::attach(BarinkWindow* window)
{
	
	windows.push_back(window);

	// Attach callbacks
	glfwSetKeyCallback(window->windowptr(), KeyCallback);
	glfwSetCursorPosCallback(window->windowptr(), CursorPositionCallback);
	glfwSetCursorEnterCallback(window->windowptr(), CursorEnterCallback);
	glfwSetMouseButtonCallback(window->windowptr(), MouseButtonCallback);
	glfwSetScrollCallback(window->windowptr(), ScrollCallback);

}

BarinkEngine::InputManager::InputManager()
{
	windows = std::vector<BarinkWindow*>();
}
